aboutsummaryrefslogtreecommitdiffstats
path: root/cmake/modules/FindPCRE.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/modules/FindPCRE.cmake')
-rw-r--r--cmake/modules/FindPCRE.cmake14
1 files changed, 8 insertions, 6 deletions
diff --git a/cmake/modules/FindPCRE.cmake b/cmake/modules/FindPCRE.cmake
index 73d6d00bdd..120adb421b 100644
--- a/cmake/modules/FindPCRE.cmake
+++ b/cmake/modules/FindPCRE.cmake
@@ -1,15 +1,15 @@
# - Find pcre
# Find the native PCRE includes and library
#
-# PCRE_INCLUDE_DIR - where to find pcre.h, etc.
-# PCRE_LIBRARIES - List of libraries when using pcre.
-# PCRE_FOUND - True if pcre found.
+# PCRE_INCLUDE_DIRS - where to find pcre.h, etc.
+# PCRE_LIBRARIES - List of libraries when using pcre.
+# PCRE_FOUND - True if pcre found.
-IF (PCRE_INCLUDE_DIR)
+IF (PCRE_INCLUDE_DIRS)
# Already in cache, be silent
SET(PCRE_FIND_QUIETLY TRUE)
-ENDIF (PCRE_INCLUDE_DIR)
+ENDIF (PCRE_INCLUDE_DIRS)
FIND_PATH(PCRE_INCLUDE_DIR pcre.h)
@@ -23,8 +23,10 @@ FIND_PACKAGE_HANDLE_STANDARD_ARGS(PCRE DEFAULT_MSG PCRE_LIBRARY PCRE_INCLUDE_DIR
IF(PCRE_FOUND)
SET( PCRE_LIBRARIES ${PCRE_LIBRARY} )
+ SET( PCRE_INCLUDE_DIRS ${PCRE_INCLUDE_DIR} )
ELSE(PCRE_FOUND)
SET( PCRE_LIBRARIES )
+ SET( PCRE_INCLUDE_DIRS )
ENDIF(PCRE_FOUND)
-MARK_AS_ADVANCED( PCRE_LIBRARY PCRE_INCLUDE_DIR )
+MARK_AS_ADVANCED( PCRE_LIBRARIES PCRE_INCLUDE_DIRS )